@@ -13,10 +13,11 @@ calc_timx_result <- function(op, infile, dimension_data, var_name, na.rm, p) {
       op,
       max = {do.call(pmax, c(na.rm = TRUE, lapply(seq_len(dim(dum_dat)[3]), function(i) dum_dat[, , i])))},
       min = {do.call(pmin, c(na.rm = TRUE, lapply(seq_len(dim(dum_dat)[3]), function(i) dum_dat[, , i])))},
-      mean = {rowMeans(dum_dat, dims = 2, na.rm = na.rm)},
+      mean = {rowMeans(dum_dat, dims = 2, na.rm = TRUE)},
       sum = {rowSums(dum_dat, dims = 2, na.rm = na.rm)},
       sd = {apply(dum_dat, c(1, 2), stats::sd, na.rm = TRUE)},
-      pctl = {apply(dum_dat, c(1, 2), stats::quantile, probs = p, names = FALSE, na.rm = TRUE)}
+	  pctl = {apply(dum_dat, c(1, 2), stats::quantile, probs = p, names = FALSE, na.rm = TRUE)},
+	  avg = {rowMeans(dum_dat, dims = 2, na.rm = FALSE)}
     )
   } else {
     nr_of_possible_x_dims <- round(
@@ -44,10 +45,11 @@ calc_timx_result <- function(op, infile, dimension_data, var_name, na.rm, p) {
           op,
           max = {do.call(pmax, c(na.rm = TRUE, lapply(seq_len(dim(dum_dat)[3]), function(i) dum_dat[, , i])))},
           min = {do.call(pmin, c(na.rm = TRUE, lapply(seq_len(dim(dum_dat)[3]), function(i) dum_dat[, , i])))},
-          mean = {rowMeans(dum_dat, dims = 2, na.rm = na.rm)},
+          mean = {rowMeans(dum_dat, dims = 2, na.rm = TRUE)},
           sum = {rowSums(dum_dat, dims = 2, na.rm = na.rm)},
           sd = {apply(dum_dat, c(1, 2), stats::sd, na.rm = TRUE)},
-          pctl = {apply(dum_dat, c(1, 2), stats::quantile, probs = p, names = FALSE, na.rm = TRUE)}
+		  pctl = {apply(dum_dat, c(1, 2), stats::quantile, probs = p, names = FALSE, na.rm = TRUE)},
+		  avg = {rowMeans(dum_dat, dims = 2, na.rm = FALSE)}
         )
     }
   }
